==> brush-0.2.23.tar.gz: brush-brush-shell-v0.2.23/brush-shell/tests/integration_tests.rs <==
//! Integration tests for brush shell

// For now, only compile this for Unix-like platforms (Linux, macOS).
#![cfg(unix)]
#![allow(clippy::panic_in_result_fn)]

use anyhow::Context;
use predicates::prelude::PredicateBooleanExt;

#[test]
fn get_version_variables() -> anyhow::Result<()> {
    let shell_path = assert_cmd::cargo::cargo_bin("brush");
    let brush_ver_str = get_variable(&shell_path, "BRUSH_VERSION")?;
    let bash_ver_str = get_variable(&shell_path, "BASH_VERSION")?;

    assert_eq!(brush_ver_str, env!("CARGO_PKG_VERSION"));
    assert_ne!(
        brush_ver_str, bash_ver_str,
        "Should differ for scripting use-case"
    );

    Ok(())
}

#[test]
fn version_exit_code() -> anyhow::Result<()> {
    let mut cmd = assert_cmd::Command::cargo_bin("brush")?;
    let assert = cmd.arg("--version").assert();
    assert
        .success()
        .stdout(predicates::str::contains(env!("CARGO_PKG_VERSION")));

    Ok(())
}

#[test]
fn help_exit_code() -> anyhow::Result<()> {
    let mut cmd = assert_cmd::Command::cargo_bin("brush")?;
    let assert = cmd.arg("--help").assert();
    assert.success().stdout(predicates::str::is_empty().not());

    Ok(())
}

#[test]
fn invalid_option_exit_code() -> anyhow::Result<()> {
    let mut cmd = assert_cmd::Command::cargo_bin("brush")?;
    let assert = cmd.arg("--unknown-argument-here").assert();
    assert
        .failure()
        .stderr(predicates::str::contains("unexpected argument"));

    Ok(())
}

fn get_variable(shell_path: &std::path::Path, var: &str) -> anyhow::Result<String> {
    let output = std::process::Command::new(shell_path)
        .arg("--norc")
        .arg("--noprofile")
        .arg("-c")
        .arg(format!("echo -n ${{{var}}}"))
        .output()
        .with_context(|| format!("failed to retrieve {var}"))?
        .stdout;
    Ok(String::from_utf8(output)?)
}

==> brush-0.3.0.tar.gz: brush-brush-shell-v0.3.0/brush-shell/tests/integration_tests.rs <==
//! Integration tests for brush shell

// For now, only compile this for Unix-like platforms (Linux, macOS).
#![cfg(unix)]
#![allow(clippy::panic_in_result_fn)]

use anyhow::Context;
use predicates::prelude::PredicateBooleanExt;

#[test]
fn get_version_variables() -> anyhow::Result<()> {
    let shell_path = assert_cmd::cargo::cargo_bin!("brush");
    let brush_ver_str = get_variable(shell_path, "BRUSH_VERSION")?;
    let bash_ver_str = get_variable(shell_path, "BASH_VERSION")?;

    assert_eq!(brush_ver_str, env!("CARGO_PKG_VERSION"));
    assert_ne!(
        brush_ver_str, bash_ver_str,
        "Should differ for scripting use-case"
    );

    Ok(())
}

#[test]
fn version_exit_code() {
    let mut cmd = assert_cmd::cargo::cargo_bin_cmd!("brush");
    let assert = cmd.arg("--version").assert();
    assert
        .success()
        .stdout(predicates::str::contains(env!("CARGO_PKG_VERSION")));
}

#[test]
fn help_exit_code() {
    let mut cmd = assert_cmd::cargo::cargo_bin_cmd!("brush");
    let assert = cmd.arg("--help").assert();
    assert.success().stdout(predicates::str::is_empty().not());
}

#[test]
fn invalid_option_exit_code() {
    let mut cmd = assert_cmd::cargo::cargo_bin_cmd!("brush");
    let assert = cmd.arg("--unknown-argument-here").assert();
    assert
        .failure()
        .stderr(predicates::str::contains("unexpected argument"));
}

fn get_variable(shell_path: &std::path::Path, var: &str) -> anyhow::Result<String> {
    let output = std::process::Command::new(shell_path)
        .arg("--norc")
        .arg("--noprofile")
        .arg("-c")
        .arg(format!("echo -n ${{{var}}}"))
        .output()
        .with_context(|| format!("failed to retrieve {var}"))?
        .stdout;
    Ok(String::from_utf8(output)?)
}
